@@ -1,5 +1,5 @@
 context("Synthetic class")
 
 test_that("Synthetic is a matrix", {
-  expect_equal(class(synthetic), "matrix")
-})
\ No newline at end of file
+  expect_equal(inherits(synthetic, "matrix"), TRUE)
+})
